Welcome to SquidASM's documentation!
====================================
This is the documentation for SquidASM, a simulator based on NetSquid that can execute applications written using NetQASM.

To get started with SquidASM see the :ref:`install guide<label_installation>`.
Afterwards a :ref:`tutorial <label_start_tutorial>` is available to introduce SquidASM step by step.
We also provide :ref:`API <label_api_overview>` documentation.


.. toctree::
   :maxdepth: 1
   :caption: Installation

   installation

.. toctree::
   :maxdepth: 2
   :caption: Tutorial:
   :glob:

   tutorial/*


.. toctree::
   :maxdepth: 2
   :caption: API

   api_overview
